@@ -1,10 +1,14 @@
 import itertools
 import json
+import getpass
+import os
 import urllib.parse
 import urllib.request
+import contextlib
 from typing import Dict, Callable
 
 import xmltodict
+from jaraco.context import suppress
 from more_itertools import always_iterable
 
 
@@ -56,6 +60,26 @@ class Client:
     def __init__(self, app_id):
         self.app_id = app_id
 
+    @classmethod
+    def from_env(cls):
+        """
+        Create a client with a key discovered from the keyring
+        or environment variable. Raises an exception if no key
+        is found.
+        """
+        return cls(cls._from_keyring() or cls._from_env())
+
+    @staticmethod
+    @suppress(Exception)
+    def _from_keyring():
+        import keyring
+
+        return keyring.get_password('https://api.wolframalpha.com/', getpass.getuser())
+
+    @staticmethod
+    def _from_env():
+        return os.environ['WOLFRAMALPHA_API_KEY']
+
     def query(self, input, params=(), **kwargs):
         """
         Query Wolfram|Alpha using the v2.0 API
@@ -134,10 +158,8 @@ class Assumption(Document):
     @property
     def text(self):
         text = self.template.replace('${desc1}', self.description)
-        try:
+        with contextlib.suppress(Exception):
             text = text.replace('${word}', self.word)
-        except Exception:
-            pass
         return text[: text.index('. ') + 1]
 
 
@@ -212,10 +234,6 @@ class Result(ErrorHandler, Document):
     Handles processing the response for the programmer.
     """
 
-    _attr_types = dict(
-        pod=Pod.from_doc,
-    )
-
     def __init__(self, stream):
         doc = xmltodict.parse(stream, dict_constructor=dict)['queryresult']
         super(Result, self).__init__(doc)
@@ -229,7 +247,7 @@ class Result(ErrorHandler, Document):
 
     @property
     def pods(self):
-        return self.pod
+        return Pod.from_doc(self.get('pod'))
 
     @property
     def assumptions(self):
@@ -243,7 +261,10 @@ class Result(ErrorHandler, Document):
         return self.info
 
     def __len__(self):
-        return sum(1 for _ in self.info)
+        return sum(1 for _ in self)
+
+    def __bool__(self):
+        return bool(len(self))
 
     @property
     def results(self):
@@ -257,4 +278,4 @@ class Result(ErrorHandler, Document):
         """
         A simplified set of answer text by title.
         """
-        return {pod.title: pod.plaintext for pod in self.pods}
+        return {pod.title: pod.text for pod in self.pods}
