@@ -24,6 +24,10 @@ def test_results_iterator(temp_result):
     next(res.results)
 
 
+def test_result_details(temp_result):
+    assert temp_result.details
+
+
 def test_properties(temp_result):
     """
     A result should have a number of properties.
@@ -51,3 +55,37 @@ def test_invalid_app_id():
     client = wolframalpha.Client('abcdefg')
     with pytest.raises(Exception):
         client.query('30 deg C in deg F')
+
+
+def test_unsuccessful(client):
+    """
+    A result for an unsuccessful query should be False and
+    have empty info.
+    """
+    res = client.query('this is a sentence')
+    assert not res
+    assert len(res) == 0
+    assert list(res.info) == []
+
+
+def test_from_env(monkeypatch):
+    monkeypatch.delenv('WOLFRAMALPHA_API_KEY', raising=False)
+    with pytest.raises(KeyError):
+        wolframalpha.Client._from_env()
+
+
+class TestDocument:
+    def test_missing_attr(self):
+        doc = wolframalpha.Document()
+        with pytest.raises(AttributeError):
+            doc.missing
+
+
+class TestAssumption:
+    def test_text(self):
+        doc = wolframalpha.Assumption(
+            template='Assume ${desc1} and ${word}. Nothing more.',
+            description='description',
+            word='word',
+        )
+        assert doc.text == 'Assume description and word.'
